pub struct SchemaAclEntry {
pub role: String,
pub grantor: Option<String>,
pub privileges: SchemaPrivileges,
pub grant_options: SchemaPrivileges,
}Expand description
One explicit schema ACL path. None on SchemaRow::acl retains the owner-only default privileges of an ordinary newly created schema.
Fields
role: Stringgrantor: Option<String>Legacy persisted entries without an explicit grantor originate from the schema owner.
privileges: SchemaPrivilegesgrant_options: SchemaPrivilegesTrait Implementations
Sourceimpl Clone for SchemaAclEntry
impl Clone for SchemaAclEntry
Sourcefn clone(&self) -> SchemaAclEntry
fn clone(&self) -> SchemaAclEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SchemaAclEntry
impl Debug for SchemaAclEntry
Sourceimpl<'de> Deserialize<'de> for SchemaAclEntry
impl<'de> Deserialize<'de> for SchemaAclEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SchemaAclEntry
Sourceimpl PartialEq for SchemaAclEntry
impl PartialEq for SchemaAclEntry
Sourceimpl Serialize for SchemaAclEntry
impl Serialize for SchemaAclEntry
impl StructuralPartialEq for SchemaAclEntry