pub struct DocSet { /* private fields */ }Expand description
A finite set of document ids stored in ascending order.
The explicit universe passed to Self::complement determines the finite
Boolean algebra in which a complement is evaluated.
Implementations
Sourceimpl DocSet
impl DocSet
Sourcepub fn from_unsorted(doc_ids: Vec<DocId>) -> Self
pub fn from_unsorted(doc_ids: Vec<DocId>) -> Self
Construct a document set from ids in arbitrary order.
Sourcepub fn difference(&self, other: &Self) -> Self
pub fn difference(&self, other: &Self) -> Self
Set difference, self \\ other.
Sourcepub fn complement(&self, universe: &Self) -> Self
pub fn complement(&self, universe: &Self) -> Self
Complement relative to an explicit finite universe.
Sourcepub fn iter(
&self,
) -> impl ExactSizeIterator<Item = DocId> + DoubleEndedIterator + '_
pub fn iter( &self, ) -> impl ExactSizeIterator<Item = DocId> + DoubleEndedIterator + '_
Iterate over document ids in ascending order.