pub struct MemoryReservation { /* private fields */ }Expand description
A unique lease: release it only after the associated allocation has been freed.
Implementations
Sourceimpl MemoryReservation
impl MemoryReservation
pub fn bytes(&self) -> usize
pub fn budget(&self) -> &MemoryBudget
Sourcepub fn split(&mut self, bytes: usize) -> Self
pub fn split(&mut self, bytes: usize) -> Self
Transfer part of an existing allocation lease without releasing or reserving bytes.
Panics if bytes exceeds this lease. The original lease is unchanged on failure.