Conditional atomic updates using the compare/exchange interface supported by the MSRV.
Functions
- try_
update_ i32 - Return the previous value after a successful update, or the observed value when the callback returns
None. The callback can run repeatedly after contention; the orderings apply to the successful exchange and failed reads respectively. - try_
update_ u64 - Return the previous value after a successful update, or the observed value when the callback returns
None. The callback can run repeatedly after contention; the orderings apply to the successful exchange and failed reads respectively.